@@ -15,5 +15,9 @@
 import poppt
 # todo：输入文件路径
 # @except_dec()
+from office.lib.decorator_utils.instruction_url import instruction
+
+
+@instruction
 def ppt2pdf(path: str):
     poppt.ppt2pdf(path)
